==> masamune_flutter-0.1.3.tar.gz: lib/widget/uiapp.dart <==
part of masamune.flutter;

/// Widget which extended [MaterialApp] for Path
class UIApp extends UIWidget {

  /// Widget which extended [MaterialApp] for Path
  UIApp(
    {
      PathEvent load,
      PathEvent unload,
      PathEvent pause,
      PathEvent unpause,
      PathEvent quit,
      Key key,
      GlobalKey<NavigatorState> navigatorKey,
      WidgetBuilder home,
      String pagePath = DefaultPath.route,
      Map<String, WidgetBuilder> routes = const <String, WidgetBuilder>{},
      String initialRoute,      
      Route<dynamic> Function(RouteSettings) onGenerateRoute,
      Route<dynamic> Function(RouteSettings) onUnknownRoute,
      List<NavigatorObserver> navigatorObservers = const <NavigatorObserver>[],
      Widget Function(BuildContext, Widget) builder,
      String title = '',
      String Function(BuildContext) onGenerateTitle,
      Color color,
      ThemeData theme,
      ThemeData darkTheme,
      ThemeMode themeMode = ThemeMode.system,
      Locale locale, Iterable<LocalizationsDelegate<dynamic>> localizationsDelegates,
      Locale Function(List<Locale>, Iterable<Locale>) localeListResolutionCallback,
      Locale Function(Locale, Iterable<Locale>) localeResolutionCallback,
      Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')],
      bool debugShowMaterialGrid = false,
      bool showPerformanceOverlay = false,
      bool checkerboardRasterCacheImages = false,
      bool checkerboardOffscreenLayers = false,
      bool showSemanticsDebugger = false,
      bool debugShowCheckedModeBanner = true
    }
  ) : super(    
    load:load,
    unload: unload,
    pause: ( context, path ) {      
      if( pause != null ) pause( context, path );
      PathMap.onApplicationPause(true);
    },
    unpause: ( context, path ) {      
      if( unpause != null ) pause( context, path );
      PathMap.onApplicationPause(false);
    },
    quit: ( context, path ) {      
      if( quit != null ) quit( context, path );
      PathMap.onApplicationQuit( );
    },
    child: ( context ) {
      if( isNotEmpty( pagePath ) && routes != null && routes.length > 0 ){
        routes.forEach(
          (key, value){
            key = key.trimString(Const.slash);
            DataField( Paths.child(pagePath, key), value );
          }
        );
      }
      return MaterialApp(        
        key:key,
        navigatorKey:navigatorKey,
        home: home != null ? home(context) : null,
        routes:routes?.map((key, value) => MapEntry( key, (_) => value( context ) )),
        initialRoute:initialRoute,
        onGenerateRoute:onGenerateRoute,
        onUnknownRoute:onUnknownRoute,
        navigatorObservers:navigatorObservers,
        builder: builder != null ? (_, widget) => builder( context, widget ) : null,
        title:title,
        onGenerateTitle:onGenerateTitle,
        color:color,
        theme:theme,
        darkTheme:darkTheme,
        themeMode:themeMode,
        localizationsDelegates:localizationsDelegates,
        localeListResolutionCallback:localeListResolutionCallback,
        localeResolutionCallback:localeResolutionCallback,
        supportedLocales:supportedLocales,
        debugShowMaterialGrid:debugShowMaterialGrid,
        showPerformanceOverlay:showPerformanceOverlay,
        checkerboardRasterCacheImages:checkerboardRasterCacheImages,
        checkerboardOffscreenLayers:checkerboardOffscreenLayers,
        showSemanticsDebugger:showSemanticsDebugger,
        debugShowCheckedModeBanner:debugShowCheckedModeBanner
      );
    }
  );
}

==> masamune_flutter-0.2.2.tar.gz: lib/widget/uiapp.dart <==
part of masamune.flutter;

/// Widget which extended [MaterialApp] for Path.
class UIApp extends UIWidget {

  /// Widget which extended [MaterialApp] for Path.
  UIApp(
    {
      BuildEvent load,
      BuildEvent unload,
      BuildEvent pause,
      BuildEvent unpause,
      BuildEvent quit,
      Key key,
      GlobalKey<NavigatorState> navigatorKey,
      WidgetBuilder home,
      String pagePath = DefaultPath.route,
      Map<String, WidgetBuilder> routes = const <String, WidgetBuilder>{},
      String initialRoute,      
      Route<dynamic> Function(RouteSettings) onGenerateRoute,
      Route<dynamic> Function(RouteSettings) onUnknownRoute,
      List<NavigatorObserver> navigatorObservers = const <NavigatorObserver>[],
      Widget Function(BuildContext, Widget) builder,
      String title = '',
      String Function(BuildContext) onGenerateTitle,
      Color color,
      ThemeData theme,
      ThemeData darkTheme,
      ThemeMode themeMode = ThemeMode.system,
      Locale locale,
      Iterable<LocalizationsDelegate<dynamic>> localizationsDelegates,
      Locale Function(List<Locale>, Iterable<Locale>) localeListResolutionCallback,
      Locale Function(Locale, Iterable<Locale>) localeResolutionCallback,
      Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')],
      bool debugShowMaterialGrid = false,
      bool showPerformanceOverlay = false,
      bool checkerboardRasterCacheImages = false,
      bool checkerboardOffscreenLayers = false,
      bool showSemanticsDebugger = false,
      bool debugShowCheckedModeBanner = true
    }
  ) : super(    
    load:load,
    unload: unload,
    pause: ( context ) {      
      if( pause != null ) pause( context );
      PathMap.onApplicationPause(true);
    },
    unpause: ( context ) {      
      if( unpause != null ) pause( context );
      PathMap.onApplicationPause(false);
    },
    quit: ( context ) {      
      if( quit != null ) quit( context );
      PathMap.onApplicationQuit( );
    },
    child: ( context ) {
      if( isNotEmpty( pagePath ) && routes != null && routes.length > 0 ){
        routes.forEach(
          (key, value){
            key = key.trimString(Const.slash);
            DataField( Paths.child(pagePath, key), value );
          }
        );
      }
      return MaterialApp(        
        key:key,
        navigatorKey:navigatorKey,
        home: home != null ? home(context) : null,
        routes:routes?.map((key, value) => MapEntry( key, (_) => value( context ) )),
        initialRoute:initialRoute,
        onGenerateRoute:onGenerateRoute,
        onUnknownRoute:onUnknownRoute,
        navigatorObservers:
          navigatorObservers != null ?
          List<NavigatorObserver>.from( navigatorObservers ).insertLast(UIValue.routeObserver) :
          [UIValue.routeObserver],
        builder: builder != null ? (_, widget) => builder( context, widget ) : null,
        title:title,
        onGenerateTitle:onGenerateTitle,
        color:color,
        theme:theme,
        darkTheme:darkTheme,
        themeMode:themeMode,
        localizationsDelegates:localizationsDelegates,
        localeListResolutionCallback:localeListResolutionCallback,
        localeResolutionCallback:localeResolutionCallback,
        supportedLocales:supportedLocales,
        debugShowMaterialGrid:debugShowMaterialGrid,
        showPerformanceOverlay:showPerformanceOverlay,
        checkerboardRasterCacheImages:checkerboardRasterCacheImages,
        checkerboardOffscreenLayers:checkerboardOffscreenLayers,
        showSemanticsDebugger:showSemanticsDebugger,
        debugShowCheckedModeBanner:debugShowCheckedModeBanner
      );
    }
  );
}
